# Fast CMA-ES
Fast Python implementation of the CMA-ES optimization algorithm.

- [README](https://github.com/dietmarwo/fast-cma-es/blob/master/README.adoc)
- [Tutorial](https://github.com/dietmarwo/fast-cma-es/blob/master/Tutorial.adoc)
- [Results](https://github.com/dietmarwo/fast-cma-es/blob/master/Results.adoc)
- [QnA](https://github.com/dietmarwo/fast-cma-es/blob/master/QnA.adoc)
